@@ -1,6 +1,20 @@
 #battle.py
 #Copyright (C) 2005 Free Software Foundation
-#see GPL.txt for license.
+#This file is part of Dragon Hunt.
+
+#Dragon Hunt is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
+
+#Dragon Hunt is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+
+#You should have received a copy of the GNU General Public License
+#along with Dragon Hunt; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #this file controls the window_battle window.
 
@@ -57,6 +71,10 @@ base_mon_hp_height = []
 #the currently selected monster.
 active_button = -1
 
+#gem usage stuff
+used_gem = 0
+num_dice = 1
+old_attack = 0
 
 #refreshes the battle view. Call after changing anything.
 def refresh():
@@ -88,7 +106,9 @@ def refresh():
 	#clear and rebuild listbox_item
 	listbox_item.delete(0, END)
 	for i in g.item.inv:
-		if i != -1 and (g.item.item[i].type == 11 or g.item.item[i].type == 12):
+		if i != -1 and (g.item.item[i].type == 11 or
+				g.item.item[i].type == 12 or
+				g.item.item[i].type == 14):
 			listbox_item.insert(END, g.item.item[i].name)
 
 	#clear and rebuild listbox_skill
@@ -113,6 +133,13 @@ def attack(event=0):
 	#Both hp's *should* be over 0. Just a precaution.
 	if monster_list[last_mon_num].hp > 0 and g.hp > 0:
 		attack_monster(last_mon_num)
+	global used_gem
+	global num_dice
+	if used_gem == 1:
+	   g.adj_attack = old_attack
+	   main.attack.set(g.adj_attack)
+	   num_dice = 1
+	   used_gem = 0
 	attack_player()
 	if can_leave() == 0:
 		active_button = -1
@@ -237,7 +264,8 @@ def attack_monster(i):
 	if i == -1: return
 	global cur_mon_hp
 	#find the damage done
-	damage = g.die_roll(1, g.adj_attack + 2)
+	global num_dice
+	damage = g.die_roll(num_dice, g.adj_attack + 2)
 	damage = damage - g.die_roll(1, monster_list[i].defense + 2)
 	if damage > 0:
  		main.print_message("You hit the " + monster_list[i].name +
@@ -404,6 +432,24 @@ def useitem():
 		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
 		attack_player()
 
+	#if item is a gem
+	if item_type == 14:
+		global old_attack
+		old_attack = g.adj_attack
+		gem_power = g.item.item[item_value].quality
+		#gem power increases attack strength potential
+		g.adj_attack = g.adj_attack + gem_power * 0.75
+		#gem power increases num_dice (ie. chance to hit and total damage)
+		global num_dice
+		num_dice = num_dice + gem_power/4
+		main.print_message("The " + g.item.item[item_value].name +
+			    " focuses the power of your attack.")
+		main.attack.set(g.adj_attack)
+		g.item.drop_inv_item(g.item.find_inv_item(item_value))
+		global used_gem
+		used_gem=1
+		attack()
+
 	#if item is explosive
 	if item_type == 12:
 		sel_mon = select_monster()
@@ -921,7 +967,7 @@ def begin(mon_index_input):
 		canvas_mon_pic.create_text(xstart,
 			base_mon_hp_y_start[i]+7, anchor=N, text="", tags="mon_hp"+str(i))
 
-	try: hero_pic = g.tiles["people/hero_n.png"]
+	try: hero_pic = g.tiles["people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"]
 	except KeyError: hero_pic = ImageTk.PhotoImage("RGB", (32, 32))
 	canvas_mon_pic.create_image(
 				background_pic.width()/2,
