@@ -1,9 +1,22 @@
 #file: map_editor.py
 #Copyright (C) 2005 Free Software Foundation
-#see GPL.txt for license.
+#This file is part of Dragon Hunt.
+
+#Dragon Hunt is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
+
+#Dragon Hunt is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+
+#You should have received a copy of the GNU General Public License
+#along with Dragon Hunt; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # This file runs a map editing program.
-# Currently, loading maps does not work.
 # Author: Allison Marles
 # Date: Sept.1, 2004
 
@@ -845,7 +858,7 @@ def make_menus():
 	mapmode_menu.add_command(label='Replace Tile (default)', command=(lambda x="replace":set_mode(x)))
 	mapmode_menu.add_command(label='Add Tile (transparency)', command=(lambda x="add":set_mode(x)))
 	mapmode_menu.add_command(label='Reset Tile (clear to background)', command=(lambda x="remove":set_mode(x)))
-	mapmode_menu.add_command(label='Adjust walkable staus', command=(lambda x="walkable":set_mode(x)))
+	mapmode_menu.add_command(label='Adjust walkable status', command=(lambda x="walkable":set_mode(x)))
 	mapmode_menu.add_command(label='Edit scripting', command=(lambda x="scripting":set_mode(x)))
 
 	#mapsize submenu
